pub fn default_im_pt_detect() -> ImPtDetectCfgExpand description
Default configuration for detecting features brighter or darker than background
pub fn default_im_pt_detect() -> ImPtDetectCfgDefault configuration for detecting features brighter or darker than background