StandaloneArgs

Struct StandaloneArgs 

pub struct StandaloneArgs {
    pub camera_name: Option<String>,
    pub http_server_addr: Option<String>,
    pub pixel_format: Option<String>,
    pub force_camera_sync_mode: bool,
    pub software_limit_framerate: StartSoftwareFrameRateLimit,
    pub acquisition_duration_allowed_imprecision_msec: Option<f64>,
    pub camera_settings_filename: Option<PathBuf>,
}
CLI args for the case when we run standalone.

Fields

camera_name: Option<String>http_server_addr: Option<String>

The HTTP socket address for the Strand Cam BUI.

pixel_format: Option<String>force_camera_sync_mode: bool

If set, camera acquisition will external trigger.

software_limit_framerate: StartSoftwareFrameRateLimit

If enabled, limit framerate (FPS) at startup.

Despite the name (“software”), this actually sets the hardware acquisition rate via the AcquisitionFrameRate camera parameter.

acquisition_duration_allowed_imprecision_msec: Option<f64>

Threshold duration before logging error (msec).

If the image acquisition timestamp precedes the computed trigger timestamp, clearly an error has happened. This error must lie in the computation of the trigger timestamp. This specifies the threshold error at which an error is logged. (The underlying source of such errors remains unknown.)

camera_settings_filename: Option<PathBuf>

Filename of vendor-specific camera settings file.